@@ -1,11 +1,12 @@
 from os import makedirs, system, path, stat
+import subprocess
 import time
 import pathlib
-from semver import VersionInfo
+from semver import VersionInfo, process
 from cement import Controller, ex
 from ..core.config import load_config
 from ..core.utils import create_boilerplate, render_boilerplate, get_plugin_info, get_plugin_path, show_schema
-from ..core.tech_local import TestLocal
+from ..core.test_local import TestLocal
 from ..core.message_log import Log
 from ..core.aws_s3 import S3
 
@@ -165,6 +166,10 @@ class Crawler(Controller):
             }), (['--major'], {
                 "action": "store_true",
                 "dest": "major_flag"
+            }),
+            (['--verbose'], {
+                "action": 'store_true',
+                "dest": "verbose"
             })
         ]
     )
@@ -198,19 +203,14 @@ class Crawler(Controller):
             plugin_names.append(input_plugin_name)
 
         for plugin_name in plugin_names:
-            print(f'Initiating Deplyment for: {plugin_name} ')
+            print(f'Deploying: {plugin_name} ')
 
             plugin_name = plugin_name.strip()
 
             plugin_dir_path = get_plugin_path(plugin_name, all_types=True)
 
             if(plugin_dir_path):
-                # system(f"""
-                # cd {plugin_dir_path} && 
-                # cd .. &&
-                # git pull 
-                # """)
-          
+
                 plugin_info = get_plugin_info(plugin_dir_path)
                 version_path = '{}/.version'.format(plugin_dir_path)
                 if(path.exists(version_path)):
@@ -244,24 +244,40 @@ class Crawler(Controller):
 
                     self.app.log.info(
                         "[{}] [{}] {}".format(deploy_type, version_info, deploy_message))
+                try:
+                    cmd = f"""
+                        cd {plugin_dir_path} &&
+                        cd .. &&
+                        git stash --quiet &&
+                        git pull origin master --quiet &&
+                        git stash apply --quiet &&
+                        git add {plugin_name}/  &&
+                        git commit -m "[{deploy_type}] [{version_info}] {deploy_message}" --quiet &&
+                        git push origin master --quiet
+                        """
 
-                command = """
-                cd {} &&
-                cd .. &&
-                git add {}/ &&
-                git commit -m "[{}] [{}] {}" &&
-                git pull && 
-                git push
-                """.format(plugin_dir_path, plugin_name, deploy_type, version_info, deploy_message)
+                    if self.app.pargs.verbose is True:
+                        cmd = f"""
+                        cd {plugin_dir_path} &&
+                        cd .. &&
+                        git stash &&
+                        git pull origin master &&
+                        git stash apply &&
+                        git add {plugin_name}/ &&
+                        git commit -m "[{deploy_type}] [{version_info}] {deploy_message}" &&
+                        git push origin master
+                        """
 
-                # sleep for 2 second to make it look real deployment
-                time.sleep(2)
+                    subprocess.run(
+                        cmd, shell=True, check=True)
+
+                except subprocess.CalledProcessError:
+                    self.app.log.error(
+                        f'There was a problem deploying {plugin_name}')
+                    return
 
                 show_schema(plugin_dir_path)
-
-                system(command)
-                # sleep for 2 second to make it look real deployment
-                time.sleep(2)
+                # sleep for a while to fake a real deployment.
                 try:
                     app_url = f'https://appnext.grepsr.com/projects/{plugin_info["pid"]}'
                     self.app.log.info(f"App Url: {app_url}")
@@ -272,8 +288,6 @@ class Crawler(Controller):
                         f"Cannot find pid in plugin, please find the project's url manually")
                     self.app.log.info(
                         f"Plugin: {plugin_name} deployed successfully")
-            else:
-                self.app.log.error(f'plugin: {plugin_name} was not found')
 
     @ex(
         help="use a base plugin from: https://bitbucket.org/grepsr/vortex-plugins-services-base",
@@ -342,4 +356,4 @@ class Crawler(Controller):
             system(
                 f""" cd {target_plugin_path} &&  composer install""")
         else:
-            Log.error(f"Target plugin: {target_plugin_name} not found")
\ No newline at end of file
+            Log.error(f"Target plugin: {target_plugin_name} not found")
