@@ -160,7 +160,7 @@ def get_plugin_info(plugin_path):
                     'desc': desc
                 }
         except:
-            Log.warn("Cannot find the Plugin's Info")
+            pass
 
 
 def render_boilerplate(boilerplate, data, destination_path):
